@@ -4,11 +4,11 @@ from celery import Celery
 from celery.utils.log import get_task_logger
 from dotenv import load_dotenv
 from .models import create_all
-import basic_crud as basic_crud
-import find_user as find_user
-import user_interactions as user_interactions
-import song_interactions as song_interactions
-import playlist_interactions as play_inter
+from .basic_crud import *
+from .find_user import *
+from .user_interactions import *
+from .song_interactions import *
+from .playlist_interactions import *
 from .databaseseed import has_news, seed_news
 from .socialTasks import get_news_db
 from .dump_user import create_dump, retrieve_latest_dump
@@ -38,57 +38,57 @@ def get_latest_dump():
 # Create
 @app.task()
 def add_user(first_name, last_name, email, username, password):
-    return basic_crud.add_user(first_name, last_name, email, username, password)
+    return add_user(first_name, last_name, email, username, password)
 
 
 # Read
 @app.task()
 def get_users():
-    return basic_crud.get_users()
+    return get_users()
 
 
 # Read user @ id
 @app.task()
 def get_user(user_id):
-    return basic_crud.get_user(user_id)
+    return get_user(user_id)
 
 
 # Update first/last @ id
 @app.task()
 def update_user(user_id, first, last):
-    return basic_crud.update_user(user_id, first, last)
+    return update_user(user_id, first, last)
 
 
 # Delete
 @app.task()
 def delete_user(user_id):
-    return basic_crud.delete_user(user_id)
+    return delete_user(user_id)
 
 
 # Authentication
 @app.task()
 def login(username, password):
-    return user_interactions.login(username, password)
+    return login(username, password)
 
 
 @app.task()
 def register(username, first_name, last_name, email, password):
-    return user_interactions.register(username, first_name, last_name, email, password)
+    return register(username, first_name, last_name, email, password)
 
 
 @app.task()
 def logout(session_token):
-    return user_interactions.logout(session_token)
+    return logout(session_token)
 
 
 @app.task()
 def token_valid(session_token):
-    return user_interactions.user_session_valid(session_token)
+    return user_session_valid(session_token)
 
 
 @app.task()
 def user_info_from_session_token(session_token):
-    return user_interactions.user_info_from_session_token(session_token)
+    return user_info_from_session_token(session_token)
 
 
 # User Methods
@@ -110,41 +110,41 @@ def find_user_by(method, params):
 # Like system functions
 @app.task()
 def get_liked_songs(song_list, user_id):
-    return song_interactions.get_liked_songs(song_list, user_id)
+    return get_liked_songs(song_list, user_id)
 
 
 @app.task()
 def get_liked_song(song_id, user_id):
-    return song_interactions.get_liked_song(song_id, user_id)
+    return get_liked_song(song_id, user_id)
 
 
 @app.task()
 def like_song(genius_id, user_id):
-    return song_interactions.like_song(genius_id, user_id)
+    return like_song(genius_id, user_id)
 
 
 @app.task()
 def dislike_song(genius_id, user_id):
-    return song_interactions.dislike_song(genius_id, user_id)
+    return dislike_song(genius_id, user_id)
 
 
 @app.task()
 def add_song(name, artist, genre, genius_id):
-    return song_interactions.add_song(name, artist, genre, genius_id)
+    return add_song(name, artist, genre, genius_id)
 
 
 @app.task()
 def find_song(name, artist):
-    return song_interactions.find_song(name, artist)
+    return find_song(name, artist)
 
 @app.task()
 def update_views(genius_id):
-    song_interactions.increaseView(genius_id)
+    increaseView(genius_id)
     # to-do call increase views
 
 @app.task()
 def get_views(genius_id):
-    return song_interactions.getView(genius_id)
+    return getView(genius_id)
     # Celery Test Code
 
 @app.task()
@@ -159,38 +159,38 @@ def get_news():
 # Playlist functions
 @app.task()
 def new_playlist(name, token):
-    return play_inter.new_playlist(name, user_interactions.user_info_from_session_token(token)[0])
+    return new_playlist(name, user_info_from_session_token(token)[0])
 
 
 @app.task()
 def get_user_playlists(token):
-    return play_inter.get_user_playlists(user_interactions.user_info_from_session_token(token)[0])
+    return get_user_playlists(user_info_from_session_token(token)[0])
 
 
 @app.task()
 def update_playlist_name(token, playlist_id, new_name):
-    return play_inter.update_playlist_name(playlist_id, new_name, user_interactions.user_info_from_session_token(token)[0])
+    return update_playlist_name(playlist_id, new_name, user_info_from_session_token(token)[0])
 
 
 @app.task()
 def delete_playlist(playlist_id, token):
-    return play_inter.delete_playlist(playlist_id, user_interactions.user_info_from_session_token(token)[0])
+    return delete_playlist(playlist_id, user_info_from_session_token(token)[0])
 
 
 # Playlist content CRUD
 @app.task()
 def show_playlist_content(playlist_id):
-    return play_inter.show_playlist_content(playlist_id)
+    return show_playlist_content(playlist_id)
 
 
 @app.task()
 def add_song_to_playlist(song_id, playlist_id, token):
-    return play_inter.add_song_to_playlist(song_id, playlist_id, user_interactions.user_info_from_session_token(token)[0])
+    return add_song_to_playlist(song_id, playlist_id, user_info_from_session_token(token)[0])
 
 
 @app.task()
 def remove_song_from_playlist(song_id, playlist_id, token):
-    return play_inter.remove_song_from_playlist(song_id, playlist_id, user_interactions.user_info_from_session_token(token)[0])
+    return remove_song_from_playlist(song_id, playlist_id, user_info_from_session_token(token)[0])
 
 @app.task()
 def run_dump():
